@@ -1,25 +1,11 @@
+//  SPDX-FileCopyrightText: 1998 Matthias Hoelzer <hoelzer@kde.org>
+//  SPDX-FileCopyrightText: 2002, 2016 David Faure <faure@kde.org>
+//  SPDX-FileCopyrightText: 2005 Brad Hards <bradh@frogmouth.net>
+//  SPDX-FileCopyrightText: 2008 Dmitry Suzdalev <dimsuz@gmail.com>
+//  SPDX-FileCopyrightText: 2011 Kai Uwe Broulik <kde@privat.broulik.de>
+//  SPDX-FileCopyrightText: 2020 Tristan Miller <psychonaut@nothingisreal.com>
 //
-//  Copyright (C) 1998 Matthias Hoelzer <hoelzer@kde.org>
-//  Copyright (C) 2002, 2016 David Faure <faure@kde.org>
-//  Copyright (C) 2005 Brad Hards <bradh@frogmouth.net>
-//  Copyright (C) 2008 by Dmitry Suzdalev <dimsuz@gmail.com>
-//  Copyright (C) 2011 Kai Uwe Broulik <kde@privat.broulik.de>
-//  Copyright (C) 2020 Tristan Miller <psychonaut@nothingisreal.com>
-//
-//  This program is free software; you can redistribute it and/or modify
-//  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
-//  (at your option) any later version.
-//
-//  This program is distributed in the hope that it will be useful,
-//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
-//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//  GNU General Public License for more details.
-//
-//  You should have received a copy of the GNU General Public License
-//  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-//
+//  SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "config-kdialog.h"
 #include "widgets.h"
@@ -101,7 +87,7 @@ bool WinIdEmbedder::eventFilter(QObject *o, QEvent *e)
 {
     if (e->type() == QEvent::Show && o->isWidgetType()
         && o->inherits("QDialog")) {
-        QWidget *w = static_cast<QWidget *>(o);
+        auto *w = static_cast<QWidget *>(o);
         if (print) {
             cout << "winId: " << w->winId() << endl;
         }
@@ -306,8 +292,8 @@ int main(int argc, char *argv[])
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("detailederror"), i18n("'Error' message box with expandable Details field"), QStringLiteral("text> <details")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("msgbox"), i18n("Message Box dialog"), QStringLiteral("text")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("inputbox"), i18n("Input Box dialog"), QStringLiteral("text> <init")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("imgbox"), i18n("Image Box dialog"), QLatin1String("file")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("imginputbox"), i18n("Image Box Input dialog"), QLatin1String("file> <text")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("imgbox"), i18n("Image Box dialog"), QStringLiteral("file")));
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("imginputbox"), i18n("Image Box Input dialog"), QStringLiteral("file> <text")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("password"), i18n("Password dialog"), QStringLiteral("text")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("newpassword"), i18n("New Password dialog"), QStringLiteral("text")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("textbox"), i18n("Text Box dialog"), QStringLiteral("file")));
@@ -410,7 +396,7 @@ int main(int argc, char *argv[])
     }
 
     // --yesno and other message boxes
-    KMessageBox::DialogType type = static_cast<KMessageBox::DialogType>(0);
+    auto type = static_cast<KMessageBox::DialogType>(0);
     QMessageBox::Icon icon = QMessageBox::Question;
     QByteArray option;
     if (parser.isSet(QStringLiteral("yesno"))) {
@@ -493,7 +479,7 @@ int main(int argc, char *argv[])
 
         QDialog dialog;
         dialog.setWindowTitle(title);
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(&dialog);
+        auto *buttonBox = new QDialogButtonBox(&dialog);
         KMessageBox::Options options = KMessageBox::NoExec;
 
         switch (type) {
@@ -537,7 +523,7 @@ int main(int argc, char *argv[])
         if (!dontagain.isEmpty()) {
             // We use NoExec in order to call handleXGeometry before exec
             // But that means we need to query the state of the dontShowAgain checkbox ourselves too...
-            QCheckBox *cb = dialog.findChild<QCheckBox *>();
+            auto *cb = dialog.findChild<QCheckBox *>();
             Q_ASSERT(cb);
             if (cb && cb->isChecked()) {
                 if (type == KMessageBox::WarningContinueCancel) {
@@ -629,9 +615,9 @@ int main(int argc, char *argv[])
                                                       passiveicon,
                                                       (QWidget *)nullptr, // parent
                                                       timeout);
-        QTimer *timer = new QTimer();
+        auto *timer = new QTimer();
         QObject::connect(timer, SIGNAL(timeout()), qApp, SLOT(quit()));
-        QObject::connect(popup, SIGNAL(clicked()), qApp, SLOT(quit()));
+        QObject::connect(popup, QOverload<>::of(&KPassivePopup::clicked), qApp, &QApplication::quit);
         timer->setSingleShot(true);
         timer->start(timeout);
 
