@@ -31,7 +31,7 @@
 
 static void addButtonBox(QDialog &dlg, QDialogButtonBox::StandardButtons buttons = QDialogButtonBox::Ok | QDialogButtonBox::Cancel)
 {
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(buttons, &dlg);
+    auto *buttonBox = new QDialogButtonBox(buttons, &dlg);
     dlg.layout()->addWidget(buttonBox);
     QObject::connect(buttonBox, &QDialogButtonBox::accepted, &dlg, &QDialog::accept);
     QObject::connect(buttonBox, &QDialogButtonBox::rejected, &dlg, &QDialog::reject);
@@ -88,9 +88,9 @@ int Widgets::textBox(QWidget *parent, int width, int height, const QString &titl
     QDialog dlg(parent);
     dlg.setWindowTitle(title);
 
-    QVBoxLayout *mainLayout = new QVBoxLayout(&dlg);
+    auto *mainLayout = new QVBoxLayout(&dlg);
 
-    KTextEdit *edit = new KTextEdit(&dlg);
+    auto *edit = new KTextEdit(&dlg);
     mainLayout->addWidget(edit);
     edit->setReadOnly(true);
     edit->setFocus();
@@ -130,9 +130,9 @@ int Widgets::imgBox(QWidget *parent, const QString &title, const QString &file)
     QDialog dlg(parent);
     dlg.setWindowTitle(title);
 
-    QVBoxLayout *mainLayout = new QVBoxLayout(&dlg);
+    auto *mainLayout = new QVBoxLayout(&dlg);
 
-    QLabel *label = new QLabel(&dlg);
+    auto *label = new QLabel(&dlg);
     mainLayout->addWidget(label);
 
     addButtonBox(dlg, QDialogButtonBox::Ok);
@@ -159,20 +159,20 @@ int Widgets::imgInputBox(QWidget *parent, const QString &title, const QString &f
     QDialog dlg(parent);
     dlg.setWindowTitle(title);
 
-    QVBoxLayout *mainLayout = new QVBoxLayout(&dlg);
+    auto *mainLayout = new QVBoxLayout(&dlg);
 
     if (!text.isEmpty()) {
-        QLabel *head = new QLabel(&dlg);
+        auto *head = new QLabel(&dlg);
         head->setText(text);
         mainLayout->addWidget(head);
     }
 
-    QLabel *label = new QLabel(&dlg);
+    auto *label = new QLabel(&dlg);
     mainLayout->addWidget(label);
 
     label->setPixmap(QPixmap(file));
 
-    QLineEdit *edit = new QLineEdit(&dlg);
+    auto *edit = new QLineEdit(&dlg);
     mainLayout->addWidget(edit);
     edit->setReadOnly(false);
     edit->setFocus();
@@ -193,15 +193,15 @@ int Widgets::textInputBox(QWidget *parent, int width, int height, const QString
 {
     QDialog dlg(parent);
     dlg.setWindowTitle(title);
-    QVBoxLayout *mainLayout = new QVBoxLayout(&dlg);
+    auto *mainLayout = new QVBoxLayout(&dlg);
 
     if (!text.isEmpty()) {
-        QLabel *label = new QLabel(&dlg);
+        auto *label = new QLabel(&dlg);
         mainLayout->addWidget(label);
         label->setText(text);
     }
 
-    KTextEdit *edit = new KTextEdit(&dlg);
+    auto *edit = new KTextEdit(&dlg);
     mainLayout->addWidget(edit);
     edit->setReadOnly(false);
     edit->setFocus();
@@ -225,12 +225,12 @@ bool Widgets::comboBox(QWidget *parent, const QString &title, const QString &tex
     QDialog dlg(parent);
     dlg.setWindowTitle(title);
 
-    QVBoxLayout *mainLayout = new QVBoxLayout(&dlg);
+    auto *mainLayout = new QVBoxLayout(&dlg);
 
-    QLabel *label = new QLabel(&dlg);
+    auto *label = new QLabel(&dlg);
     label->setText(text);
     mainLayout->addWidget(label);
-    QComboBox *combo = new QComboBox(&dlg);
+    auto *combo = new QComboBox(&dlg);
     combo->addItems(args);
     combo->setCurrentIndex(combo->findText(defaultEntry));
     combo->setFocus();
@@ -353,12 +353,12 @@ bool Widgets::slider(QWidget *parent, const QString &title, const QString &text,
     QDialog dlg(parent);
     dlg.setWindowTitle(title);
 
-    QVBoxLayout *mainLayout = new QVBoxLayout(&dlg);
+    auto *mainLayout = new QVBoxLayout(&dlg);
 
-    QLabel *label = new QLabel(&dlg);
+    auto *label = new QLabel(&dlg);
     mainLayout->addWidget(label);
     label->setText(text);
-    QSlider *slider = new QSlider(&dlg);
+    auto *slider = new QSlider(&dlg);
     mainLayout->addWidget(slider);
     slider->setMinimum(minValue);
     slider->setMaximum(maxValue);
@@ -385,12 +385,12 @@ bool Widgets::calendar(QWidget *parent, const QString &title, const QString &tex
     QDialog dlg(parent);
     dlg.setWindowTitle(title);
 
-    QVBoxLayout *mainLayout = new QVBoxLayout(&dlg);
+    auto *mainLayout = new QVBoxLayout(&dlg);
 
-    QLabel *label = new QLabel(&dlg);
+    auto *label = new QLabel(&dlg);
     mainLayout->addWidget(label);
     label->setText(text);
-    KDatePicker *dateWidget = new KDatePicker(defaultEntry, &dlg);
+    auto *dateWidget = new KDatePicker(defaultEntry, &dlg);
     mainLayout->addWidget(dateWidget);
     dateWidget->setFocus();
     addButtonBox(dlg);
